/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.uiengine.fileresolver;

import org.tinygroup.fileresolver.impl.AbstractFileProcessor;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.springutil.SpringUtil;
import org.tinygroup.uiengine.config.UIComponents;
import org.tinygroup.uiengine.manager.UIComponentManager;
import org.tinygroup.vfs.FileObject;
import org.tinygroup.xstream.XStreamFactory;

import com.thoughtworks.xstream.XStream;

/**
 * UI组件定义文件
 * 
 * @author luoguo
 * 
 */
public class UIComponentFileProcessor extends AbstractFileProcessor {

	public boolean isMatch(FileObject fileObject) {
		if (fileObject.getFileName().endsWith(".ui.xml")) {
			return true;
		}
		return false;
	}

	public void clean() {

	}

	public void process() {
		UIComponentManager manager = SpringUtil
				.getBean(UIComponentManager.UIComponentManager_BEAN);
		XStream stream = XStreamFactory
				.getXStream(UIComponentManager.UIComponentManager_XSTREAM);
		for (FileObject fileObject : fileObjects) {
			logger.logMessage(LogLevel.INFO, "正在加载uicomponent文件[{0}]",
					fileObject.getAbsolutePath());
			UIComponents uiComponents = (UIComponents) stream
					.fromXML(fileObject.getInputStream());
			manager.addUIComponents(uiComponents);
			logger.logMessage(LogLevel.INFO, "加载uicomponent文件[{0}]结束",
					fileObject.getAbsolutePath());
		}
	}

}
